==> kdebugsettings-18.08.3.tar.xz: kdebugsettings-18.08.3/src/kdeloggingcategory.cpp <==
/*
  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#include "kdeloggingcategory.h"

KdeLoggingCategory::KdeLoggingCategory()
{
}

bool KdeLoggingCategory::operator ==(const KdeLoggingCategory &other) const
{
    return (description == other.description)
           && (logName == other.logName) && (defaultCategory == other.defaultCategory);
}

bool KdeLoggingCategory::operator !=(const KdeLoggingCategory &other) const
{
    return !operator==(other);
}

bool KdeLoggingCategory::isValid() const
{
    return !logName.isEmpty();
}

QDebug operator<<(QDebug d, const KdeLoggingCategory &cat)
{
    d << "description: " << cat.description;
    d << "logname: " << cat.logName;
    d << "default category: " << cat.defaultCategory;
    return d;
}

==> kdebugsettings_18.12.3.orig.tar.xz: kdebugsettings-18.12.3/src/kdeloggingcategory.cpp <==
/*
  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#include "kdeloggingcategory.h"

KdeLoggingCategory::KdeLoggingCategory()
{
}

bool KdeLoggingCategory::operator ==(const KdeLoggingCategory &other) const
{
    return (description == other.description)
           && (categoryName == other.categoryName)
           && (defaultSeverity == other.defaultSeverity)
           && (identifierName == other.identifierName);
}

bool KdeLoggingCategory::operator !=(const KdeLoggingCategory &other) const
{
    return !operator==(other);
}

bool KdeLoggingCategory::isValid() const
{
    return !categoryName.isEmpty();
}

QDebug operator<<(QDebug d, const KdeLoggingCategory &cat)
{
    d << "description: " << cat.description;
    d << "logname: " << cat.categoryName;
    d << "default category: " << cat.defaultSeverity;
    d << "identifier: " << cat.identifierName;
    return d;
}
